@@ -3,6 +3,7 @@ import AnsiblePhasePreview from './AnsiblePhasePreview'
 import PreviewGenerator from '../../../helpers/HostedEngineSetup/PreviewGenerator'
 import {deploymentStatus as status} from "../constants";
 import {footerButtons} from "../../common/Wizard/Wizard";
+import ReviewGenerator from "../../../helpers/HostedEngineSetup/ReviewGenerator";
 
 class AnsiblePhasePreviewContainer extends Component {
     constructor(props) {
@@ -22,6 +23,7 @@ class AnsiblePhasePreviewContainer extends Component {
     customActionBtnCallback() {
         this.setState({ executionStarted: true });
         const newBtnState = {
+            buttonText: this.props.executeBtnText,
             disabled: true,
             disableBtnsList: [footerButtons.BACK],
             hideBtnsList: [footerButtons.NEXT, footerButtons.FINISH, footerButtons.CLOSE]
@@ -37,7 +39,7 @@ class AnsiblePhasePreviewContainer extends Component {
         let btnState = {};
         if (executionStatus === status.FAILURE) {
             btnState = {
-                buttonText: "Execute",
+                buttonText: this.props.executeBtnText,
                 hideBtnsList: [footerButtons.NEXT],
                 buttonCallBack: function() {
                     buttonCallBack();
@@ -59,7 +61,7 @@ class AnsiblePhasePreviewContainer extends Component {
             this.state.executionStatus !== status.SUCCESS) {
             const self = this;
             const newBtnState = {
-                buttonText: "Execute",
+                buttonText: this.props.executeBtnText,
                 buttonCallBack: self.customActionBtnCallback,
                 moveNext: false,
                 overrideFinish: true
@@ -72,7 +74,7 @@ class AnsiblePhasePreviewContainer extends Component {
         let newBtnState = {};
         if (this.state.executionStatus !== status.SUCCESS) {
             newBtnState = {
-                buttonText: "Execute",
+                buttonText: this.props.executeBtnText,
                 buttonCallBack: this.customActionBtnCallback,
                 hideBtnsList: [footerButtons.NEXT, footerButtons.FINISH]
             };
@@ -81,9 +83,18 @@ class AnsiblePhasePreviewContainer extends Component {
         }
     }
 
+    shouldComponentUpdate(nextProps, nextState) {
+        if (!this.props.validating && nextProps.validating) {
+            const allowFwdStepChg = this.state.executionTerminated && this.state.executionStatus === status.SUCCESS;
+            this.props.validationCallBack(allowFwdStepChg);
+        }
+
+        return true;
+    }
+
     render() {
-        const previewGen = new PreviewGenerator(this.state.heSetupModel);
-        const sections = previewGen.getPreviewSections(this.props.sections);
+        const reviewGen = new ReviewGenerator(this.state.heSetupModel);
+        const sections = reviewGen.getReviewSections(this.props.sections);
 
         return (
             <AnsiblePhasePreview abortCallBack={this.props.abortCallBack}
